# automatix
Automation wrapper for bash and python commands. Extended Features version.


# DESCRIPTION

All the work of this fork is integrated and continued in the original
repository now. Please use https://github.com/seibert-media/automatix.

To switch your installation remove automatix_cmd and install automatix
thereafter.

    pip uninstall automatix_cmd
    pip install automatix
